bandsdosplot — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# bandsdosplot

pyprocar.scripts.bandsdosplot(bands_settings: dict = {'atoms': {}, 'ax': None, 'code': 'plain', 'dirname': None, 'elimit': True, 'fermi': 1, 'fermi_shift': 'cubic', 'interpolation_factor': None, 'interpolation_type': None, 'items': 0, 'kdirect': None, 'knames': None, 'kticks': True, 'mode': None, 'orbitals': None, 'print_plot_opts': True, 'projection_mask': None, 'savefig': None, 'show': False, 'spins': None}, dos_settings: dict = {'atoms': None, 'ax': None, 'code': 'vasp', 'dirname': None, 'dos_limit': None, 'elimit': None, 'export_append_mode': True, 'export_data_file': None, 'fermi': None, 'fermi_shift': 0, 'items': {}, 'labels': None, 'mode': 'plain', 'normalize_dos_mode': None, 'orbitals': None, 'orientation': 'horizontal', 'print_plot_opts': False, 'projection_mask': None, 'savefig': None, 'show': True, 'spins': None}, dos_limit: List[int] | None = None, elimit: List[int] | None = None, k_limit=None, grid: bool = False, code: str = 'vasp', lobster: bool = False, savefig: str | None = None, title: str | None = None, title_fontsize: float = 16, discontinuities=None, draw_fermi: bool = True, plot_color_bar: bool = True, repair: bool = True, show: bool = True, **kwargs)

  A function to plot the band structure and the density of states in the same plot

  Parameters:

    - bands_settings (dict, optional) – A dictionary containing the keyword arguments from bandsplot, by default bands_settings

    - dos_settings (dict, optional) – A dictionary containing the keyword arguments from dosplot, by default dos_settings

    - dos_limit (List[int], optional) – The dos window to plot, by default None

    - elimit (List[int], optional) – The energy window to plot, by default None

    - k_limit (_type_, optional) – The kpath points to plot, by default None

    - grid (bool, optional) – Boolean to plot a grid, by default False

    - code (str, optional) – The code to use, by default “vasp”

    - lobster (bool, optional) – Boolean if this is a lobster calculation, by default False

    - savefig (str, optional) – The filename to to save the plot as., by default None

    - title (str, optional) – String for the title name, by default None

    - title_fontsize (float, optional) – Float for the title size, by default 16

    - discontinuities (_type_, optional) – _description_, by default None

    - draw_fermi (bool, optional) – Boolean to plot the fermi level, by default True

    - plot_color_bar (bool, optional) – Boolean to plot the color bar, by default True

    - repair (bool, optional) – Boolean to repair the PROCAR file, by default True

    - show (bool, optional) – Boolean to show the plot, by default True